@@ -55,6 +55,7 @@ from google.cloud.container_v1.types.cluster_service import (
     DeleteNodePoolRequest,
     DnsCacheConfig,
     DNSConfig,
+    EphemeralStorageLocalSsdConfig,
     FastSocket,
     GatewayAPIConfig,
     GcePersistentDiskCsiDriverConfig,
@@ -89,6 +90,7 @@ from google.cloud.container_v1.types.cluster_service import (
     ListOperationsResponse,
     ListUsableSubnetworksRequest,
     ListUsableSubnetworksResponse,
+    LocalNvmeSsdBlockConfig,
     LoggingComponentConfig,
     LoggingConfig,
     LoggingVariantConfig,
@@ -165,6 +167,7 @@ from google.cloud.container_v1.types.cluster_service import (
     UsableSubnetworkSecondaryRange,
     VerticalPodAutoscaling,
     VirtualNIC,
+    WindowsNodeConfig,
     WorkloadIdentityConfig,
     WorkloadMetadataConfig,
 )
@@ -201,6 +204,7 @@ __all__ = (
     "DeleteNodePoolRequest",
     "DnsCacheConfig",
     "DNSConfig",
+    "EphemeralStorageLocalSsdConfig",
     "FastSocket",
     "GatewayAPIConfig",
     "GcePersistentDiskCsiDriverConfig",
@@ -234,6 +238,7 @@ __all__ = (
     "ListOperationsResponse",
     "ListUsableSubnetworksRequest",
     "ListUsableSubnetworksResponse",
+    "LocalNvmeSsdBlockConfig",
     "LoggingComponentConfig",
     "LoggingConfig",
     "LoggingVariantConfig",
@@ -306,6 +311,7 @@ __all__ = (
     "UsableSubnetworkSecondaryRange",
     "VerticalPodAutoscaling",
     "VirtualNIC",
+    "WindowsNodeConfig",
     "WorkloadIdentityConfig",
     "WorkloadMetadataConfig",
     "DatapathProvider",
