@@ -44,6 +44,7 @@ from .cluster_service import (
     DeleteNodePoolRequest,
     DnsCacheConfig,
     DNSConfig,
+    EphemeralStorageLocalSsdConfig,
     FastSocket,
     GatewayAPIConfig,
     GcePersistentDiskCsiDriverConfig,
@@ -78,6 +79,7 @@ from .cluster_service import (
     ListOperationsResponse,
     ListUsableSubnetworksRequest,
     ListUsableSubnetworksResponse,
+    LocalNvmeSsdBlockConfig,
     LoggingComponentConfig,
     LoggingConfig,
     LoggingVariantConfig,
@@ -154,6 +156,7 @@ from .cluster_service import (
     UsableSubnetworkSecondaryRange,
     VerticalPodAutoscaling,
     VirtualNIC,
+    WindowsNodeConfig,
     WorkloadIdentityConfig,
     WorkloadMetadataConfig,
 )
@@ -188,6 +191,7 @@ __all__ = (
     "DeleteNodePoolRequest",
     "DnsCacheConfig",
     "DNSConfig",
+    "EphemeralStorageLocalSsdConfig",
     "FastSocket",
     "GatewayAPIConfig",
     "GcePersistentDiskCsiDriverConfig",
@@ -221,6 +225,7 @@ __all__ = (
     "ListOperationsResponse",
     "ListUsableSubnetworksRequest",
     "ListUsableSubnetworksResponse",
+    "LocalNvmeSsdBlockConfig",
     "LoggingComponentConfig",
     "LoggingConfig",
     "LoggingVariantConfig",
@@ -293,6 +298,7 @@ __all__ = (
     "UsableSubnetworkSecondaryRange",
     "VerticalPodAutoscaling",
     "VirtualNIC",
+    "WindowsNodeConfig",
     "WorkloadIdentityConfig",
     "WorkloadMetadataConfig",
     "DatapathProvider",
